@@ -2,7 +2,7 @@
  *                 Mathematical Object Library                 *
  *     class symmatrix:  declarations for symmetric matrix     *
  *                    simula.plus@cemes.fr                     *
- *                   GNU/linux version 3.0.0                   *
+ *                   GNU/linux version 3.2.0                   *
  *            software under General Public License            *
  ***************************************************************
  * copyright © 2002,2003,2004,2005,2006,2007,2008,2009,2010,2012 COLLARD Christophe
@@ -54,7 +54,7 @@
 	     copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
 	     copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV) \endhtmlonly \n
 	     copyright \htmlonly &#169; 2010, 2012 Centre d'Elaboration de Mat&#233;riaux et d'Etudes Structurales (CEMES - CNRS) \endhtmlonly \n
-    \version 3.0.0
+    \version 3.2.0
     \date 2002-2012
     \bug none
     \warning none
@@ -255,7 +255,7 @@ template <class T> symmatrix<T>& symmatrix<T>::operator = (const symmatrix<T>& m
 {
   assert (mat.nbRows && mat.nbColumns);
 
-  if (!nbRows) create (mat.nbRows,mat.nbColumns);
+  if (!nbRows) this -> create (mat.nbRows,mat.nbColumns);
   else assert (nbRows == mat.nbRows);
 
   for (int i=0; i<nbRows; i++)
