@@ -2,7 +2,7 @@
  *                 Mathematical Object Library                 *
  *      class tensor3 : declarations for 3rd order tensors     *
  *                    simula.plus@cemes.fr                     *
- *                   GNU/linux version 3.0.0                   *
+ *                   GNU/linux version 3.2.0                   *
  *            software under General Public License            *
  ***************************************************************
  * copyright © 2004,2005,2006,2007,2008,2009,2012 COLLARD Christophe
@@ -51,7 +51,7 @@
 	    copyright \htmlonly &#169; 2004, 2005, 2006, 2007, 2008, 2009 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
 	    copyright \htmlonly &#169; 2004, 2005, 2006, 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV) \endhtmlonly \n
 	    copyright \htmlonly &#169; 2012 Centre d'Elaboration de Mat&#233;riaux et d'Etudes Structurales (CEMES - CNRS) \endhtmlonly \n
-    \version 3.0.0
+    \version 3.2.0
     \date 2004-2012
     \bug none
     \warning none
@@ -109,29 +109,33 @@ template <class T> class tensor3
     virtual tensor3<T>& operator = (tensor3<T>*);  // allocates the data from the right hand temporary object to the left hand object - no copy (deletes temporary object)
     virtual tensor3<T>& operator &= (const tensor3<T>&); // copies tensor3 without size check (use this operator with great care)
     virtual tensor3<T>& operator &= (tensor3<T>*); // allocates the data from the right hand temporary object to the left hand object (deletes temporary object) - no size check - no copy (use this operator with great care)
-    template <class M> friend tensor3<M>  operator + (const tensor3<M>&, const tensor3<M>&); // overloads operator + for 3rd order tensors
-    template <class M> friend tensor3<M>  operator - (const tensor3<M>&, const tensor3<M>&); // overloads operator - for 3rd order tensors
-    template <class M> friend M           operator | (const tensor3<M>&, const tensor3<M>&);  // overloads operator | for 3rd order tensors T|P = Tijk Pijk
+    template <class Tf> friend tensor3<Tf>  operator + (const tensor3<Tf>&, const tensor3<Tf>&); // overloads operator + for 3rd order tensors
+    template <class Tf> friend tensor3<Tf>  operator - (const tensor3<Tf>&, const tensor3<Tf>&); // overloads operator - for 3rd order tensors
+    template <class Tf> friend Tf           operator | (const tensor3<Tf>&, const tensor3<Tf>&);  // overloads operator | for 3rd order tensors T|P = Tijk Pijk
     tensor3<T>& operator += (const tensor3<T>&);  // overloads += operator for tensors
     tensor3<T>& operator -= (const tensor3<T>&);  // overloads -= operator for tensors
-    template <class M> friend bool operator == (const tensor3<M>&, const tensor3<M>&);  // compares 2 tensors
-    template <class M> friend bool operator != (const tensor3<M>&, const tensor3<M>&);
+    template <class Tf> friend bool operator == (const tensor3<Tf>&, const tensor3<Tf>&);  // compares 2 tensors
+    template <class Tf> friend bool operator != (const tensor3<Tf>&, const tensor3<Tf>&);
     // operations with scalars
     tensor3<T>& operator *= (const T&);
-    template <class M> friend tensor3<M> operator * (const tensor3<M>&, const M&);
-    template <class M> friend tensor3<M> operator * (const M&, const tensor3<M>&);
+    tensor3<T>& operator /= (const T&);
+    template <class Tf> friend tensor3<Tf> operator * (const tensor3<Tf>&, const Tf&);
+    template <class Tf> friend tensor3<Tf> operator * (const Tf&, const tensor3<Tf>&);
+    template <class Tf> friend tensor3<Tf> operator / (const tensor3<Tf>&, const Tf&);
     // operations with vectors
-    template <class M> friend tensor2<M> operator * (const tensor3<M>&, const vector<M>&);   // M_ki = P_kij * V_j
-    template <class M> friend tensor2<M> operator * (const vector<M>&, const tensor3<M>&);   // M_ij = P_kij * V_k
-    template <class M> friend tensor2<M> operator | (const tensor3<M>&, const vector<M>&);   // M_kj = P_kij * V_i
-    template <class M> friend tensor2<M> operator | (const vector<M>&, const tensor3<M>&);   // M_kj = P_kij * V_i
-    template <class M> friend tensor2<M> tensor_sum (const tensor3<M>&, const vector<M>&, int);  // M = P : v
+    template <class Tf> friend tensor2<Tf> operator * (const tensor3<Tf>&, const vector<Tf>&);   // M_ki = P_kij * V_j
+    template <class Tf> friend tensor2<Tf> operator * (const vector<Tf>&, const tensor3<Tf>&);   // M_ij = P_kij * V_k
+    template <class Tf> friend tensor2<Tf> operator | (const tensor3<Tf>&, const vector<Tf>&);   // M_kj = P_kij * V_i
+    template <class Tf> friend tensor2<Tf> operator | (const vector<Tf>&, const tensor3<Tf>&);   // M_kj = P_kij * V_i
+    template <class Tf> friend tensor2<Tf> tensor_sum (const tensor3<Tf>&, const vector<Tf>&, int);  // M = P : v
     // operations with tensor2
-    template <class M> friend vector<M> operator || (const tensor3<M>&, const tensor2<M>&);   // v_p = T_p,ij M_ij
-    template <class M> friend tensor3<M> operator * (const tensor2<M>&, const tensor3<M>&);   // T_pij = M_pq * T_qij
+    template <class Tf> friend vector<Tf>  operator || (const tensor3<Tf>&, const tensor2<Tf>&);  // v_p = T_p,ij M_ij
+    template <class Tf> friend tensor3<Tf> operator * (const tensor2<Tf>&, const tensor3<Tf>&);   // T_pij = Msh ru_pq * T_qij
+    template <class Tf> friend tensor3<Tf> operator ^ (const tensor2<Tf>&, const vector<Tf>&);    // T_ijp = M_ij * V_p
+    template <class Tf> friend tensor3<Tf> operator ^ (const vector<Tf>&, const tensor2<Tf>&);    // T_pij = V_p * M_ij
     // overloads iostreams
-    template <class M> friend ostream& operator << (ostream&, const tensor3<M>&);  // overloads output stream for tensors
-    template <class M> friend istream& operator >> (istream&, const tensor3<M>&);  // overloads output stream for tensors
+    template <class Tf> friend ostream& operator << (ostream&, const tensor3<Tf>&);  // overloads output stream for tensors
+    template <class Tf> friend istream& operator >> (istream&, const tensor3<Tf>&);  // overloads output stream for tensors
     virtual void save (const char*);   // writes to disk
     virtual void save (const string&); // writes to disk
     virtual void read (const char*);   // reads from disk
@@ -357,36 +361,36 @@ template <class T> tensor3<T>& tensor3<T>::operator &= (tensor3<T>* tn)
 }
 
 
-//-----------------------------------------------------------------------------------
-template <class T> tensor3<T> operator + (const tensor3<T>& t1, const tensor3<T>& t2)
-//-----------------------------------------------------------------------------------
+//---------------------------------------------------------------------------------------
+template <class Tf> tensor3<Tf> operator + (const tensor3<Tf>& t1, const tensor3<Tf>& t2)
+//---------------------------------------------------------------------------------------
 {
   assert (t1.dim1()==t2.dim1()); // tensors must have the same size
   assert(t1.dim1());
-  tensor3<T> t = t1;
+  tensor3<Tf> t = t1;
   return t+=t2;
 }
 
 
-//-----------------------------------------------------------------------------------
-template <class T> tensor3<T> operator - (const tensor3<T>& t1, const tensor3<T>& t2)
-//-----------------------------------------------------------------------------------
+//---------------------------------------------------------------------------------------
+template <class Tf> tensor3<Tf> operator - (const tensor3<Tf>& t1, const tensor3<Tf>& t2)
+//---------------------------------------------------------------------------------------
 {
   assert (t1.dim1()==t2.dim1()); // tensors must have the same size
   assert(t1.dim1());
-  tensor3<T> t = t1;
+  tensor3<Tf> t = t1;
   return t-=t2;
 }
 
 
-//--------------------------------------------------------------------------
-template <class T> T operator | (const tensor3<T>& t1, const tensor3<T>& t2)
-//--------------------------------------------------------------------------
+//------------------------------------------------------------------------------
+template <class Tf> Tf operator | (const tensor3<Tf>& t1, const tensor3<Tf>& t2)
+//------------------------------------------------------------------------------
 {
   assert (t1.size==t2.size); // tensors must have the same size
   assert (t1.size);
 
-  T sum=0;
+  Tf sum=0;
   for (int i=1; i<=t1.size; i++)
     sum += (t1[i] | t2[i]);
 
@@ -422,9 +426,9 @@ template <class T> tensor3<T>& tensor3<T>::operator -= (const tensor3<T>& ts)
 }
 
 
-//------------------------------------------------------------------------------
-template <class T> bool operator == (const tensor3<T>& t1, const tensor3<T>& t2)
-//------------------------------------------------------------------------------
+//---------------------------------------------------------------------------------
+template <class Tf> bool operator == (const tensor3<Tf>& t1, const tensor3<Tf>& t2)
+//---------------------------------------------------------------------------------
 {
   assert (t1.size);
 
@@ -436,9 +440,9 @@ template <class T> bool operator == (const tensor3<T>& t1, const tensor3<T>& t2)
 }
 
 
-//------------------------------------------------------------------------------
-template <class T> bool operator != (const tensor3<T>& t1, const tensor3<T>& t2)
-//------------------------------------------------------------------------------
+//---------------------------------------------------------------------------------
+template <class Tf> bool operator != (const tensor3<Tf>& t1, const tensor3<Tf>& t2)
+//---------------------------------------------------------------------------------
 {
   return !(t1 == t2);
 }
@@ -449,39 +453,66 @@ template <class T> tensor3<T>& tensor3<T>::operator *= (const T& elt)
 //-------------------------------------------------------------------
 {
   assert (size);
+
   for (int i=0; i<size; i++)
     tsr [i] *= elt;
+
   return *this;
 }
 
 
-//---------------------------------------------------------------------------
-template <class T> tensor3<T> operator * (const tensor3<T>& ts, const T& elt)
-//---------------------------------------------------------------------------
+//-------------------------------------------------------------------
+template <class T> tensor3<T>& tensor3<T>::operator /= (const T& elt)
+//-------------------------------------------------------------------
 {
-  assert (ts.size);
-  tensor3<T> tr = ts;
-  return tr*=elt;
+  assert (size);
+  assert (elt);
+
+  for (int i=0; i<size; i++)
+    tsr [i] /= elt;
+
+  return *this;
 }
 
 
-//---------------------------------------------------------------------------
-template <class T> tensor3<T> operator * (const T& elt, const tensor3<T>& ts)
-//---------------------------------------------------------------------------
+//-------------------------------------------------------------------------------
+template <class Tf> tensor3<Tf> operator * (const tensor3<Tf>& ts, const Tf& elt)
+//-------------------------------------------------------------------------------
 {
   assert (ts.size);
-  return ts*elt;
+  tensor3<Tf> tr = ts;
+  return tr *= elt;
 }
 
 
-//---------------------------------------------------------------------------------
-template <class T> tensor2<T> operator * (const tensor3<T>& ts, const vector<T>& v)
-//---------------------------------------------------------------------------------
+//-------------------------------------------------------------------------------
+template <class Tf> tensor3<Tf> operator * (const Tf& elt, const tensor3<Tf>& ts)
+//-------------------------------------------------------------------------------
+{
+  assert (ts.size);
+  return ts * elt;
+}
+
+
+//-------------------------------------------------------------------------------
+template <class Tf> tensor3<Tf> operator / (const tensor3<Tf>& ts, const Tf& elt)
+//-------------------------------------------------------------------------------
+{
+  assert (ts.size);
+  assert (elt);
+  tensor3<Tf> tr = ts;
+  return tr /= elt;
+}
+
+
+//-------------------------------------------------------------------------------------
+template <class Tf> tensor2<Tf> operator * (const tensor3<Tf>& ts, const vector<Tf>& v)
+//-------------------------------------------------------------------------------------
 {
   assert (v.dim());
   assert (v.dim() == ts.dim3());
 
-  tensor2<T> m(ts.dim1(),ts.dim2());
+  tensor2<Tf> m(ts.dim1(),ts.dim2());
   for (int k=1; k<=ts.size; k++)
     m[k] += ts[k] * v;
 
@@ -489,14 +520,14 @@ template <class T> tensor2<T> operator * (const tensor3<T>& ts, const vector<T>&
 }
 
 
-//---------------------------------------------------------------------------------
-template <class T> tensor2<T> operator * (const vector<T>& v, const tensor3<T>& ts)
-//---------------------------------------------------------------------------------
+//-------------------------------------------------------------------------------------
+template <class Tf> tensor2<Tf> operator * (const vector<Tf>& v, const tensor3<Tf>& ts)
+//-------------------------------------------------------------------------------------
 {
   assert (v.dim());
   assert (v.dim() == ts.dim1());
 
-  tensor2<T> m(ts.dim2(),ts.dim3());
+  tensor2<Tf> m(ts.dim2(),ts.dim3());
   for (int k=1; k<=ts.size; k++)
     m += ts[k] * v[k];
 
@@ -504,14 +535,14 @@ template <class T> tensor2<T> operator * (const vector<T>& v, const tensor3<T>&
 }
 
 
-//---------------------------------------------------------------------------------
-template <class T> tensor2<T> operator | (const tensor3<T>& ts, const vector<T>& v)
-//---------------------------------------------------------------------------------
+//-------------------------------------------------------------------------------------
+template <class Tf> tensor2<Tf> operator | (const tensor3<Tf>& ts, const vector<Tf>& v)
+//-------------------------------------------------------------------------------------
 {
   assert (v.dim());
   assert (v.dim() == ts.dim2());
 
-  tensor2<T> m(ts.dim1(),ts.dim3());
+  tensor2<Tf> m(ts.dim1(),ts.dim3());
   for (int k=1; k<=ts.size; k++)
     m[k] += v * ts[k];
 
@@ -519,21 +550,21 @@ template <class T> tensor2<T> operator | (const tensor3<T>& ts, const vector<T>&
 }
 
 
-//---------------------------------------------------------------------------------
-template <class T> tensor2<T> operator | (const vector<T>& v, const tensor3<T>& ts)
-//---------------------------------------------------------------------------------
+//-------------------------------------------------------------------------------------
+template <class Tf> tensor2<Tf> operator | (const vector<Tf>& v, const tensor3<Tf>& ts)
+//-------------------------------------------------------------------------------------
 {
   return ts|v;
 }
 
 
-//----------------------------------------------------------------------------------------
-template <class T> tensor2<T> tensor_sum (const tensor3<T>& ts, const vector<T>& v, int i)
-//----------------------------------------------------------------------------------------
+//--------------------------------------------------------------------------------------------
+template <class Tf> tensor2<Tf> tensor_sum (const tensor3<Tf>& ts, const vector<Tf>& v, int i)
+//--------------------------------------------------------------------------------------------
 {
   assert (i>=1 && i<=3);
 
-  tensor2<T> m;
+  tensor2<Tf> m;
   if (i==1) m =& (v*ts);
   else if (i==2) m =& (ts|v);
        else m =& (ts*v);
@@ -542,14 +573,14 @@ template <class T> tensor2<T> tensor_sum (const tensor3<T>& ts, const vector<T>&
 }
 
 
-//------------------------------------------------------------------------------------
-template <class T> vector<T> operator || (const tensor3<T>& ts, const tensor2<T>& mat)
-//------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------
+template <class Tf> vector<Tf> operator || (const tensor3<Tf>& ts, const tensor2<Tf>& mat)
+//----------------------------------------------------------------------------------------
 {
   assert (mat.Rows());
   assert (ts.size);
 
-  vector<T> v(ts.size,false);
+  vector<Tf> v(ts.size,false);
   for (int i=1; i<=ts.size; i++)
     v[i] = (ts[i] | mat);
 
@@ -557,14 +588,15 @@ template <class T> vector<T> operator || (const tensor3<T>& ts, const tensor2<T>
 }
 
 
-//------------------------------------------------------------------------------------
-template <class T> tensor3<T> operator * (const tensor2<T>& mat, const tensor3<T>& ts)
-//------------------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------
+template <class Tf> tensor3<Tf> operator * (const tensor2<Tf>& mat, const tensor3<Tf>& ts)
+//----------------------------------------------------------------------------------------
 {
   assert (mat.Rows());
   assert (mat.Columns() == ts.dim1());
 
-  tensor3<T> tsr(mat.Rows(),ts.dim2(),ts.dim3());
+  tensor3<Tf> tsr (mat.Rows(), ts.dim2(), ts.dim3());
+
   for (int p=1; p<=mat.Rows(); p++)
     for (int q=1; q<=ts.dim1(); q++)
       for (int i=1; i<=ts.dim2(); i++)
@@ -575,6 +607,42 @@ template <class T> tensor3<T> operator * (const tensor2<T>& mat, const tensor3<T
 }
 
 
+//-------------------------------------------------------------------------------------
+template <class Tf> tensor3<Tf> operator ^ (const tensor2<Tf>& ts, const vector<Tf>& v)
+//-------------------------------------------------------------------------------------
+{
+  assert (ts.dim1());
+  assert (v.dim());
+
+  tensor3<Tf> tsr (ts.dim1(), ts.dim2(), v.dim());
+
+  for (int i=1; i<=ts.dim1(); i++)
+    for (int j=1; j<=ts.dim2(); j++)
+      for (int p=1; p<=v.dim(); p++)
+	tsr (i,j,p) = ts(i,j) * v[p];
+
+  return tsr;
+}
+
+
+//-------------------------------------------------------------------------------------
+template <class Tf> tensor3<Tf> operator ^ (const vector<Tf>& v, const tensor2<Tf>& ts)
+//-------------------------------------------------------------------------------------
+{
+  assert (ts.dim1());
+  assert (v.dim());
+
+  tensor3<Tf> tsr (v.dim(), ts.dim1(), ts.dim2());
+
+  for (int p=1; p<=v.dim(); p++)
+    for (int i=1; i<=ts.dim1(); i++)
+      for (int j=1; j<=ts.dim2(); j++)
+	tsr (p,i,j) = ts(i,j) * v[p];
+
+  return tsr;
+}
+
+
 //------------------------------------------------------------------------
 template <class T> ostream& operator << (ostream& s, const tensor3<T>& tn)
 //------------------------------------------------------------------------
