@@ -1,6 +1,6 @@
 /***************************************************************
  *                    simula.plus@cemes.fr                     *
- *                   GNU/linux version 3.0.0                   *
+ *                   GNU/linux version 3.2.0                   *
  *            software under General Public License            *
  ***************************************************************
  * copyright © 2003,2004,2005,2006,2009,2012 COLLARD Christophe
@@ -128,6 +128,10 @@
 #include "combinatorial analysis-test.hpp"
 #endif
 
+#ifndef __gaussian_white_noise_test_hpp
+#include "gaussian white noise-test.hpp"
+#endif
+
 /*#if !defined(__ODE_TEST_H)
 #include "ode-test.h"
 #endif
@@ -149,7 +153,7 @@ main()
     //=======================================================================
     cout << "---------------------------maths--------------------------- \n";
     //=======================================================================
-  result *= test_maths(detail);
+  result *= test_maths (detail);
   end = clock();
   cout<<"cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
 
@@ -161,7 +165,7 @@ main()
     //=======================================================================
     cout << "--------------------------vector--------------------------- \n";
     //=======================================================================
-  result *= test_vector(detail);
+  result *= test_vector (detail);
   end = clock();
   cout<<"cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
 
@@ -173,7 +177,7 @@ main()
     //=======================================================================
     cout << "--------------------------matrix--------------------------- \n";
     //=======================================================================
-  result *= test_matrix(detail);
+  result *= test_matrix (detail);
   end = clock();
   cout<<"cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
 
@@ -185,7 +189,7 @@ main()
     //=======================================================================
     cout << "---------------------symmetric matrix---------------------- \n";
     //=======================================================================
-  result *= test_symmatrix(detail);
+  result *= test_symmatrix (detail);
   end = clock();
   cout<<"cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
 
@@ -197,7 +201,7 @@ main()
     //=======================================================================
     cout << "-----------------------sparse matrix----------------------- \n";
     //=======================================================================
-  result *= test_spmatrix(detail);
+  result *= test_spmatrix (detail);
   end = clock();
   cout<<"cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
 
@@ -209,7 +213,7 @@ main()
     //=======================================================================
     cout << "-----------------------linear systems---------------------- \n";
     //=======================================================================
-  result *= test_linear_systems(detail);
+  result *= test_linear_systems (detail);
   end = clock();
   cout<<"cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
 
@@ -221,7 +225,7 @@ main()
     //=======================================================================
     cout << "---------------------2nd order tensors--------------------- \n";
     //=======================================================================
-  result *= test_tensor2(detail);
+  result *= test_tensor2 (detail);
   end = clock();
   cout<<"cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
 
@@ -233,7 +237,7 @@ main()
     //=======================================================================
     cout << "----------------symmetric 2nd order tensors---------------- \n";
     //=======================================================================
-  result *= test_symtensor2(detail);
+  result *= test_symtensor2 (detail);
   end = clock();
   cout<<"cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
 
@@ -245,7 +249,7 @@ main()
     //=======================================================================
     cout << "---------------------3rd order tensors--------------------- \n";
     //=======================================================================
-  result *= test_tensor3(detail);
+  result *= test_tensor3 (detail);
   end = clock();
   cout<<"cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
 
@@ -257,7 +261,7 @@ main()
     //=======================================================================
     cout << "---------------------4th order tensor---------------------- \n";
     //=======================================================================
-  result *= test_tensor4(detail);
+  result *= test_tensor4 (detail);
   end = clock();
   cout<<"cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
 
@@ -269,7 +273,7 @@ main()
     //=======================================================================
     cout << "----------------symmetric 4th order tensor----------------- \n";
     //=======================================================================
-  result *= test_symtensor4(detail);
+  result *= test_symtensor4 (detail);
   end = clock();
   cout<<"cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
 
@@ -281,7 +285,7 @@ main()
     //=======================================================================
     cout<< "----------------------conversion tools---------------------- \n";
     //=======================================================================
-  result *= test_conversion_tools(detail);
+  result *= test_conversion_tools (detail);
   end = clock();
   cout<<"cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
 
@@ -293,7 +297,7 @@ main()
     //=======================================================================
     cout<< "------------------abaqus conversion tools------------------- \n";
     //=======================================================================
-  result *= test_abaqus_conversion_tools(detail);
+  result *= test_abaqus_conversion_tools (detail);
   end = clock();
   cout<<"cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
 
@@ -305,7 +309,7 @@ main()
     //=======================================================================
     cout<< "--------------------------polynom--------------------------- \n";
     //=======================================================================
-  result *= test_polynom(detail);
+  result *= test_polynom (detail);
   end = clock();
   cout<<"cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
 
@@ -318,7 +322,7 @@ main()
     //=======================================================================
     cout<< "------------------------function---------------------------- \n";
     //=======================================================================
-  result *= test_function(detail);
+  result *= test_function (detail);
   end = clock();
   cout<<"cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
 
@@ -331,7 +335,7 @@ main()
     //=======================================================================
     cout<< "--------------------------Legendre-------------------------- \n";
     //=======================================================================
-  result *= test_legendre(detail);
+  result *= test_legendre (detail);
   end = clock();
   cout<<"cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
 
@@ -343,7 +347,7 @@ main()
     //=======================================================================
     cout<< "-----------------------integration-------------------------- \n";
     //=======================================================================
-  result *= test_integration(detail);
+  result *= test_integration (detail);
   end = clock();
   cout<<"cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
 
@@ -355,7 +359,7 @@ main()
     //=======================================================================
     cout<< "-----------------combinatorial analysis--------------------- \n";
     //=======================================================================
-  result *= test_combinatorial_analysis(detail);
+  result *= test_combinatorial_analysis (detail);
   end = clock();
   cout<<"cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
 
@@ -368,7 +372,7 @@ main()
     //=======================================================================
     cout<< "-------------ordinary differential equations---------------- \n";
     //=======================================================================
-  result *= test_ode(detail);
+  result *= test_ode (detail);
   end = clock();
   cout<<"cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
 
@@ -378,7 +382,7 @@ main()
     //=======================================================================
     cout<< "-------------ordinary differential equations 1D------------- \n";
     //=======================================================================
-  result *= test_ode_1D(detail);
+  result *= test_ode_1D (detail);
   end = clock();
   cout<<"cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
 
@@ -390,7 +394,7 @@ main()
     //=======================================================================
     cout<< "-------------ordinary differential equations 2D------------- \n";
     //=======================================================================
-  result *= test_ode_2D(detail);
+  result *= test_ode_2D (detail);
   end = clock();
   cout<<"cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
 
@@ -402,13 +406,25 @@ main()
     //=======================================================================
     cout<< "----------------non linear equations solving---------------- \n";
     //=======================================================================
-  //  result *= test_NLE(detail);
+  //  result *= test_NLE (detail);
   end = clock();
   cout<<"cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
 
   cout << endl;
   */
 
+  detail = 0;
+  start = clock();
+  if (detail)
+    //=======================================================================
+    cout<< "------------------gaussian white noise---------------------- \n";
+    //=======================================================================
+  result *= test_gaussian_white_noise (detail);
+  end = clock();
+  cout<<"cpu time : " << (long double)(end-start)/CLOCKS_PER_SEC << endl;
+
+  cout << endl;
+
   cout << endl;
 
   end_main = clock();
